ui Package — pwman3 0.6 documentation

### Navigation

- index
- modules |
- pwman3 0.6 documentation »

# ui Package

## `ui` Package

## `baseui` Module

class `pwman.ui.baseui.` `AliasesMixin`

  Bases: `object`

  Define all the alias you want here...

  `do_EOF`(args)
  `do_cp`(args)
  `do_e`(args)
  `do_h`(arg)
  `do_ls`(args)
  `do_n`(arg)
  `do_o`(args)
  `do_p`(arg)
  `do_rm`(arg)

class `pwman.ui.baseui.` `BaseCommands`

  Bases: `pwman.ui.baseui.HelpUIMixin`, `pwman.ui.baseui.AliasesMixin`

  `do_EOF`(args)
  `do_cls`(args)

    clear the screen

  `do_copy`(args)

    copy item to clipboard

  `do_delete`(args)
  `do_edit`(args, menu=None)
  `do_exit`(args)

    close the text console

  `do_export`(args)

    export the database to a given format

  `do_forget`(args)

    drop saved key forcing the user to re-enter the master password

  `do_info`(args)
  `do_list`(args)

    list all existing nodes in database

  `do_new`(args)
  `do_open`(args)
  `do_passwd`(args)

    change the master password of the database

  `do_print`(args)
  `do_tags`(args)

    print all existing tags

  `error`(exception)

class `pwman.ui.baseui.` `HelpUIMixin`

  Bases: `object`

  this class holds all the UI help functionality. in PwmanCliNew. The later inherits from this class and allows it to print help messages to the console.

  `help_cls`()
  `help_copy`()
  `help_delete`()
  `help_edit`()
  `help_exit`()
  `help_export`()
  `help_forget`()
  `help_help`()
  `help_info`()
  `help_list`()
  `help_new`()
  `help_open`()
  `help_passwd`()
  `help_print`()
  `help_tags`()

## `cli` Module

class `pwman.ui.cli.` `PwmanCli`(db, hasxsel, callback, config_parser, **kwargs)

  Bases: `cmd.Cmd`, `pwman.ui.baseui.BaseCommands`

  Inherit from the BaseCommands and Aliases

  `undoc_header` = 'Aliases:'

`pwman.ui.cli.` `get_ui_platform`(platform)

`pwman.ui.cli.` `main`()

## `mac` Module

class `pwman.ui.mac.` `PwmanCliMac`(db, hasxsel, callback, config_parser, **kwargs)

  Bases: `pwman.ui.cli.PwmanCli`

  inherit from PwmanCli, override the right functions...

  `do_copy`(args)
  `do_open`(args)

## `tools` Module

Define the CLI interface for pwman3 and the helper functions

class `pwman.ui.tools.` `ANSI`

  Bases: `object`

  ANSI Colors

  `Black` = 30
  `Blue` = 34
  `Bold` = 1
  `Cyan` = 36
  `Green` = 32
  `Magenta` = 35
  `Red` = 31
  `Reset` = 0
  `Underscore` = 2
  `White` = 37
  `Yellow` = 33

class `pwman.ui.tools.` `CLICallback`

  Bases: `pwman.util.callback.Callback`

  `getinput`(question)
  `getnewsecret`(question)
  `getsecret`(question)

class `pwman.ui.tools.` `CMDLoop`(config)

  Bases: `object`

  The menu that drives editing of a node

  `add`(item)
  `run`(new_node=None, reader=<built-in function raw_input>)

class `pwman.ui.tools.` `CliMenuItem`(name, getter)

  Bases: `object`

`pwman.ui.tools.` `get_or_create_pass`()

`pwman.ui.tools.` `get_terminal_size`()

  getTerminalSize() - get width and height of console - works on linux,os x,windows,cygwin(windows) originally retrieved from: http://stackoverflow.com/questions/566746/how-to-get- console-window-width-in-python

`pwman.ui.tools.` `getinput`(question, default='', reader=<built-in function raw_input>, completer=None, width=10)

  http://stackoverflow.com/questions/2617057/ supply-inputs-to-python-unittests

`pwman.ui.tools.` `gettermsize`()

`pwman.ui.tools.` `open_url`(link, macosx=False)

  launch xdg-open or open in MacOSX with url

`pwman.ui.tools.` `set_selection`(new_node, items, selection, reader)

`pwman.ui.tools.` `text_to_clipboards`(text)

  copy text to clipboard credit: https://pythonadventures.wordpress.com/tag/xclip/

`pwman.ui.tools.` `text_to_mcclipboard`(text)

  copy text to mac os x clip board credit: https://pythonadventures.wordpress.com/tag/xclip/

`pwman.ui.tools.` `typeset`(text, color, bold=False, underline=False, has_colorama=True)

  print colored strings using colorama

## `win` Module

# ============================================================================ # This file is part of Pwman3. # # Pwman3 is free software; you can redistribute it and/or modify # it under the terms of the GNU General Public License, version 2 # as published by the Free Software Foundation; # # Pwman3 is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU General Public License for more details. # # You should have received a copy of the GNU General Public License # along with Pwman3; if not, write to the Free Software # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA # ============================================================================ # Copyright (C) 2012-2014 Oz Nahum Tiram <nahumoz@gmail.com> # ============================================================================ # Copyright (C) 2006 Ivan Kelly <ivan@ivankelly.net> # ============================================================================

class `pwman.ui.win.` `PwmanCliWin`(db, hasxsel, callback, config_parser, **kwargs)

  Bases: `pwman.ui.cli.PwmanCli`

  windows ui class

  `do_cls`(args)
  `do_copy`(args)
  `do_open`(args)
  `do_print`(args)

`pwman.ui.win.` `heardEnterWin`()

`pwman.ui.win.` `winGetClipboard`()

`pwman.ui.win.` `winSetClipboard`(text)

### Navigation

- index
- modules |
- pwman3 0.6 documentation »